"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.safeTouch = void 0;
function applyWithFallback(original) {
    return function tryFallback(_, __, [fallback]) {
        return original === undefined ? fallback : original;
    };
}
function noop() { }
// Using var to prevent circular referencing error on the first call
var blackHole = touch(undefined);
function touch(source) {
    if (typeof source === "undefined" && typeof blackHole !== "undefined")
        return blackHole;
    return new Proxy(noop, {
        apply: applyWithFallback(source),
        get: (_, key) => {
            if (source !== undefined &&
                source !== null &&
                Object.prototype.hasOwnProperty.call(source, key))
                return touch(source[key]);
            return blackHole;
        },
    });
}
exports.safeTouch = touch;
exports.default = touch;
